@@ -4,10 +4,14 @@
 import os
 import sys
 from pycmd.utils.pycmd import autocorrect
-import msvcrt
 import json
 from colorama import Fore as fc, init
+
 init(autoreset=True)
+try:
+    from getch import getch
+except ImportError:
+    from msvcrt import getch
 
 os.chdir(os.path.abspath(__file__ + "/../"))
 
@@ -32,9 +36,7 @@ def help(command: str):
     commands = open(f"json/commands.json", "r")
     commands = json.load(commands)
     for i in commands:
-
         if i["name"] == command:
-
             if "description" in i:
                 print(" " * (2) + f'\n{fc.YELLOW}{i["description"]}\n')
 
@@ -69,7 +71,6 @@ def help(command: str):
 
 
 def execute(command: str, parameter: str, flags: list):
-
     if not command:
         os.system("python commands/help.py help " + " ".join(flags))
         return
@@ -101,8 +102,8 @@ def execute(command: str, parameter: str, flags: list):
                 f"{fc.LIGHTBLACK_EX}[{fc.GREEN}Y{fc.LIGHTBLACK_EX}/{fc.BLUE}n{fc.LIGHTBLACK_EX}]",
                 end="\r",
             )
-            response = msvcrt.getch()
-            if response.lower() == b"y":
+            response = getch()
+            if response.lower() == "y":
                 print(fc.LIGHTGREEN_EX + "Yes  \n")
                 execute(corrected, parameter, flags)
             else:
@@ -117,7 +118,6 @@ def execute(command: str, parameter: str, flags: list):
 
 
 def main():
-
     if len(sys.argv) > 1:
         function, parameter, flags = argparse(sys.argv)
         try:
@@ -126,4 +126,4 @@ def main():
             pass
 
     else:
-        os.system("python commands/help.py")
\ No newline at end of file
+        os.system("python commands/help.py")
